@@ -28,8 +28,8 @@
 #include <QtDBus/QDBusConnectionInterface>
 #include <QtDBus/QDBusInterface>
 #include <QtDBus/QDBusReply>
-
-#include <klocale.h>
+#include <QDebug>
+#include <klocalizedstring.h>
 
 #include <unistd.h>
 
