@@ -21,7 +21,7 @@
 
 #include <QtCore/QTimer>
 #include <KDE/KDebug>
-#include <KDE/KLocale>
+#include <KDE/KLocalizedString>
 
 #include "job_p.h"
 #include "message_p.h"
@@ -344,7 +344,6 @@ void FetchJobPrivate::parseBodyStructure(const QByteArray &structure, int &pos,
 
   pos++;
 
-
   if ( structure[pos] != '(' ) { // simple part
     pos--;
     parsePart( structure, pos, content );
