@@ -19,7 +19,7 @@
 
 #include "setmetadatajob.h"
 
-#include <KDE/KLocale>
+#include <KDE/KLocalizedString>
 #include <KDE/KDebug>
 
 #include "metadatajobbase_p.h"
@@ -103,7 +103,7 @@ void SetMetaDataJob::handleResponse( const Message &response )
            response.content[2].toString() == "[METADATA TOOMANY]" ) {
         d->metaDataErrors |= TooMany;
       } else if ( response.content[2].toString() == "[ANNOTATEMORE TOOBIG]" ||
-                  response.content[2].toString().startsWith( "[METADATA MAXSIZE" ) ) {
+                  response.content[2].toString().startsWith( "[METADATA MAXSIZE" ) ) { //krazy:exclude=strings
         d->metaDataErrors |= TooBig;
         d->maxAcceptedSize = -1;
         if ( response.content[2].toString().startsWith( "[METADATA MAXSIZE" ) ) { //krazy:exclude=strings
@@ -152,4 +152,3 @@ SetMetaDataJob::MetaDataErrors SetMetaDataJob::metaDataErrors() const
   Q_D( const SetMetaDataJob );
   return d->metaDataErrors;
 }
-
