@@ -26,7 +26,7 @@
 
 #include <kio/job.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kurl.h>
 
 #include <QtCore/QVariant>
